@@ -97,7 +97,8 @@ class DownloadManager:
         elif l.type is UrlType.Url:
             return self.client.future_session.executor.submit(self.download_from_url, l)
         else:
-            return None
+            # return true because we don't want to try to download again.
+            return (True, l.link)
 
     def download(self):
         futures = [d for l in self.urls if (d := self._download(l)) is not None]
@@ -144,7 +145,7 @@ class DownloadManager:
     def process_response(self, url, response):
         if (cnt_dis := response.headers.get('Content-Disposition')) is not None:
             filename = cnt_dis.split('filename="')[1][:-1]
-            size = 1024 * 1024 * 10
+            size = 1024 * 1024 * 20
             chunk = next(response.iter_content(chunk_size=size))
             try:
                 data = chunk.decode()
